@@ -1,6 +1,6 @@
-"""
+'''
 This module contains the command line interface to atom_access
-"""
+'''
 
 import argparse
 from textwrap import dedent
@@ -9,10 +9,12 @@ import xyz_py as xyzp
 from . import utils as ut
 from .core import trace_rays, cluster_rays, cluster_size, generate_output
 import pickle
+import sys
+import os
 
 
 def tracing_func(args):
-    """
+    '''
 
     Wrapper function for ray tracing program
 
@@ -24,60 +26,86 @@ def tracing_func(args):
     Returns
     -------
     None
-
-    """
+    '''
 
     # Check requested density
     if args.density < 0:
-        exit("ZCW Densities must be >=0")
-    elif args.density > 16:
-        exit("ZCW Densities higher than 16 are not supported")
+        ut.cprint('ZCW Densities must be >=0', 'red')
+        sys.exit()
+    # elif args.density > 16:
+    #     ut.cprint('ZCW Densities higher than 16 are not supported', 'red')
+    #     sys.exit()
 
     # Load xyz file
-    labels, coords = xyzp.load_xyz(args.xyz_f_name)
+    try:
+        xyzp.check_xyz(args.xyz_f_name, allow_nonelements=True)
+    except xyzp.XYZError as xe:
+        ut.cprint(str(xe), 'red')
+        sys.exit(1)
+    labels, coords = xyzp.load_xyz(args.xyz_f_name, check=False)
     labels_nn = xyzp.remove_label_indices(labels)
 
+    # Check atom number exists
+    args.atom -= 1
+
+    if args.atom < 0 or args.atom > len(labels):
+        ut.cprint('Error: Atom index does not exist!', 'red')
+        sys.exit(1)
+
     blocked, unblocked, n_cut = trace_rays(
         labels_nn,
         coords,
-        args.atom-1,
+        args.atom,
         args.cutoff,
         args.density
     )
 
     total_rays = len(blocked) + len(unblocked)
-    pc_unblocked = len(unblocked)/(total_rays) * 100.
+    pc_unblocked = len(unblocked) / (total_rays) * 100.
 
     if not args.quiet:
-        print("\nUsing {:d} rays".format(total_rays))
-        print(
-            "Cutoff of {:f} Angstroms has been enforced, ".format(args.cutoff),
-            "{:d} atoms are completely excluded".format(n_cut)
+        ut.cprint(f'\nUsing {total_rays:d} rays', 'blue')
+        ut.cprint(
+            f'\nCutoff of {args.cutoff:f} Angstroms has been enforced',
+            'black_yellowbg'
+        )
+        ut.cprint(
+            f'{n_cut:d} atoms are completely excluded',
+            'black_yellowbg'
         )
 
-        print("{:.2f} % solid angle is visible".format(pc_unblocked))
+        ut.cprint(
+            f'\n{pc_unblocked:.2f} % of solid angle is visible',
+            'green'
+        )
+
+    if not len(unblocked):
+        if not args.quiet:
+            ut.cprint('\nAll rays are blocked', 'red')
+        sys.exit()
 
     # Cluster rays
     cluster_id = cluster_rays(unblocked, args.density)
 
-    if not cluster_id.size and args.quiet:
-        exit("All rays are blocked")
-    elif not cluster_id.size:
-        exit()
-
     # Calculate size of clusters
     clust_percent, _ = cluster_size(cluster_id, total_rays)
 
     if not args.quiet:
-        print("\nThere are {:d} clusters".format(clust_percent.size))
+        ut.cprint(
+            f'\nThere are {clust_percent.size:d} clusters',
+            'green'
+        )
 
         for idx, x in enumerate(clust_percent):
-            print(
-              "Cluster {:d} contains {:.2f} % solid angle".format(idx+1, x)
+            ut.cprint(
+                'Cluster {:d} contains {:.2f} % solid angle'.format(
+                    idx + 1, x
+                ),
+                'green'
             )
 
     # Get head of xyz file name (i.e. without extension)
-    f_head = args.xyz_f_name.split(".", 1)[0]
+    f_head = os.path.splitext(args.xyz_f_name)[0]
 
     # Print output file
     generate_output(
@@ -85,11 +113,20 @@ def tracing_func(args):
         no_header=args.quiet
     )
 
+    # Save rays, and xyz file shifted such that
+    # atom of interest is at origin.
     if args.save_rays:
-        _coords = coords - coords[args.atom-1]
-        xyzp.save_xyz("{}_shift.xyz".format(f_head), labels, _coords)
-        with open("rays.pickle", 'wb') as f:
+        print()
+        _coords = coords - coords[args.atom]
+        xyzp.save_xyz(
+            f'{f_head}_shift.xyz',
+            labels,
+            _coords,
+            comment=f'{args.xyz_f_name} coordinates shifted by atom_access'
+        )
+        with open('rays.pickle', 'wb') as f:
             pickle.dump(unblocked, f)
+        ut.cprint('Rays pickled to rays.pickle', 'green')
 
     if args.plot:
         cart_vecs = np.array([ray.cart for ray in unblocked])
@@ -99,7 +136,7 @@ def tracing_func(args):
 
 
 def read_args(arg_list=None):
-    """
+    '''
 
     Creates parser and subparsers for command line arguments
 
@@ -112,11 +149,11 @@ def read_args(arg_list=None):
     -------
     None
 
-    """
+    '''
 
-    description = """
+    description = '''
     A program for assessing steric hinderance using ray tracing
-    """
+    '''
 
     parser = argparse.ArgumentParser(
         description=description,
@@ -126,62 +163,62 @@ def read_args(arg_list=None):
     parser.set_defaults(func=tracing_func) # noqa
 
     parser.add_argument(
-        "xyz_f_name",
-        help="Name of .xyz file containing atomic coordinates"
+        'xyz_f_name',
+        help='Name of .xyz file containing atomic coordinates'
     )
 
     parser.add_argument(
-        "-a",
-        "--atom",
-        help="Index of atom for which %% visible rays is calculated.",
+        '-a',
+        '--atom',
+        help='Index of atom for which %% visible rays is calculated.',
         type=int,
         default=1
     )
 
     parser.add_argument(
-        "-d",
-        "--density",
+        '-d',
+        '--density',
         help=dedent(
-            "ZCW integration density.Integer between 0 and 16,"
-            " note - number of points does not increase linearly.\n"
+            'ZCW integration density.Integer between 0 and 16,'
+            ' note - number of points does not increase linearly.\n'
         ),
         type=int,
         default=10
     )
 
     parser.add_argument(
-        "-c",
-        "--cutoff",
+        '-c',
+        '--cutoff',
         help=dedent(
-            "Cutoff for intersection distance in Angstroms"
+            'Cutoff for intersection distance in Angstroms'
         ),
         default=5.,
         type=float,
     )
 
     parser.add_argument(
-        "-p",
-        "--plot",
+        '-p',
+        '--plot',
         help=dedent(
-            "Plot unblocked points in browser using Plotly"
+            'Plot unblocked points in browser using Plotly'
         ),
         action='store_true'
     )
 
     parser.add_argument(
-        "-sr",
-        "--save_rays",
+        '-sr',
+        '--save_rays',
         help=dedent(
-            "Pickle unblocked rays and save xyz file"
+            'Pickle unblocked rays and save xyz file'
         ),
         action='store_true'
     )
 
     parser.add_argument(
-        "-q",
-        "--quiet",
+        '-q',
+        '--quiet',
         help=dedent(
-            "Suppress print to terminal and output file header"
+            'Suppress print to terminal and output file header'
         ),
         action='store_true'
     )
